@@ -14,6 +14,7 @@ from typing import List, Optional, Tuple
 from mlcvzoo_base.api.data.bounding_box import BoundingBox
 from mlcvzoo_base.api.data.box import Box
 from mlcvzoo_base.api.data.classification import Classification
+from mlcvzoo_base.api.data.ocr_perception import OCRPerception
 from mlcvzoo_base.api.data.segmentation import Segmentation
 from mlcvzoo_base.data_preparation.structs import CSVOutputStringFormats
 
@@ -27,9 +28,9 @@ class BaseAnnotation:
     An image annotation.
     """
 
-    # Absolute file path to the image of the annotation (usually .jpg or .png
+    # Absolute file path to the image of the annotation
     image_path: str
-    # Absolute file path for the annotation (usually .xml)
+    # Absolute file path for the annotation
     annotation_path: str
 
     # shape of the image in the format (height, width)
@@ -41,6 +42,8 @@ class BaseAnnotation:
     bounding_boxes: List[BoundingBox] = field(default_factory=lambda: [])
     # List of segmentations
     segmentations: List[Segmentation] = field(default_factory=lambda: [])
+    # List of ocr perceptions (Text)
+    ocr_perception: Optional[OCRPerception] = None
 
     image_dir: str = ""
     # TODO: rename to annotation_path_dir?
