@@ -149,6 +149,40 @@ class AnnotationClassMapper:
     def annotation_class_id_to_model_class_name_map(self) -> Dict[int, str]:
         return self.__annotation_class_id_to_model_class_name_map
 
+    def create_class_identifier_list(self) -> List[ClassIdentifier]:
+        """
+        Build a list of all (output) ClassIdentifiers that are defined for this
+        AnnotationClassMapper instance. Note that one Class-ID/Class-Name can
+        have multiple mappings to ClassIdentifiers and multiple Class-IDs/Class-Names
+        can share the same ClassIdentifier.
+
+        Example mapping:
+        {
+            1: [ClassIdentifier(class_id=1, class_name="vehicle")],
+            2: [ClassIdentifier(class_id=1, class_name="vehicle")],
+            3: [
+                ClassIdentifier(class_id=15, class_name="animal"),
+                ClassIdentifier(class_id=16, class_name="cat"),
+            ],
+        }
+
+        Produces:
+        [
+            ClassIdentifier(class_id=1, class_name="vehicle"),
+            ClassIdentifier(class_id=15, class_name="animal"),
+            ClassIdentifier(class_id=16, class_name="cat")
+        ]
+
+        Returns:
+            The created list of ClassIdentifiers
+        """
+        class_identifier_list: List[ClassIdentifier] = []
+
+        for _class_identifier_list in self.__model_class_id_to_class_identifier_map.values():
+            class_identifier_list.extend(_class_identifier_list)
+
+        return class_identifier_list
+
     def get_model_class_names(self) -> List[str]:
         """
         Returns:
