@@ -12,7 +12,7 @@ import logging
 from typing import Dict, List, Optional
 
 import related
-from config_builder.BaseConfigClass import BaseConfigClass
+from config_builder import BaseConfigClass
 
 logger = logging.getLogger(__name__)
 
