@@ -9,7 +9,7 @@ import logging
 import xml.etree.ElementTree as ET_xml
 from typing import Any, Dict, List, Optional, Tuple, cast
 
-from config_builder.ConfigBuilder import ConfigBuilder
+from config_builder import ConfigBuilder
 
 from mlcvzoo_base.api.data.annotation import BaseAnnotation
 from mlcvzoo_base.api.data.annotation_class_mapper import AnnotationClassMapper
@@ -117,7 +117,6 @@ class AnnotationHandler:
                 AnnotationHandlerConfig,
                 ConfigBuilder(
                     class_type=AnnotationHandlerConfig,
-                    configuration=configuration,
                     yaml_config_path=from_yaml,
                     string_replacement_map=string_replacement_map,
                 ).configuration,
