@@ -42,6 +42,134 @@ class PascalVOCAnnotationParser(AnnotationParser):
 
         self.pascal_voc_input_data = pascal_voc_input_data
 
+    def parse(self) -> List[BaseAnnotation]:
+
+        annotations: List[BaseAnnotation] = list()
+        # Fill dictionary for implicit path replacement
+        for dataset_count, input_data_config in enumerate(self.pascal_voc_input_data):
+
+            replacement_string = AnnotationParser.csv_directory_replacement_string.format(
+                dataset_count
+            )
+
+            image_path_list, annotation_path_list = self.__determine_data_paths(
+                input_data_config=input_data_config
+            )
+
+            if input_data_config.ignore_missing_images:
+                image_path_list = len(annotation_path_list) * [""]
+            else:
+                (image_path_list, annotation_path_list,) = self.__ensure_annotations_match_images(
+                    image_path_list=image_path_list,
+                    annotation_path_list=annotation_path_list,
+                )
+
+            for image_path, annotation_path in zip(image_path_list, annotation_path_list):
+                if (
+                    not input_data_config.ignore_missing_images
+                    and os.path.realpath(input_data_config.input_image_dir)
+                    in os.path.realpath(image_path)
+                    and os.path.realpath(input_data_config.input_xml_dir)
+                    in os.path.realpath(annotation_path)
+                ) or (
+                    input_data_config.ignore_missing_images
+                    and os.path.realpath(input_data_config.input_xml_dir)
+                    in os.path.realpath(annotation_path)
+                ):
+                    try:
+                        pascal_voc_builder = PascalVOCAnnotationBuilder(
+                            mapper=self.mapper,
+                            use_difficult=input_data_config.use_difficult,
+                        )
+
+                        annotation: BaseAnnotation = pascal_voc_builder.build(
+                            image_path=image_path,
+                            annotation_path=annotation_path,
+                            image_dir=input_data_config.input_image_dir,
+                            annotation_dir=input_data_config.input_xml_dir,
+                            replacement_string=replacement_string,
+                        )
+
+                        annotations.append(annotation)
+
+                    except (ForbiddenClassError, ParseError) as error:
+
+                        logger.warning(
+                            "%s: %s, annotation '%s' will be skipped"
+                            % (type(error), str(error), annotation_path),
+                        )
+                        continue
+
+        return annotations
+
+    @staticmethod
+    def __determine_data_paths(
+        input_data_config: AnnotationHandlerPASCALVOCInputDataConfig,
+    ) -> Tuple[List[str], List[str]]:
+        """
+        Determine all image and annotations paths from the given input-data-config
+
+        Args:
+            input_data_config: The AnnotationHandlerPASCALVOCInputDataConfig that defines
+                               the input-data
+
+        Returns:
+            Tuple of image paths and annotation paths
+        """
+
+        image_paths = []
+        xml_paths = []
+
+        # CHECK SUBDIR CONFIG
+        if len(input_data_config.input_sub_dirs) > 0:
+            for sub_input_dir in input_data_config.input_sub_dirs:
+                # READ IMAGES
+                input_image_dir = os.path.join(input_data_config.input_image_dir, sub_input_dir)
+
+                image_paths.extend(
+                    get_file_list(
+                        input_dir=input_image_dir,
+                        search_subfolders=True,
+                        file_extension=f"{input_data_config.image_format}",
+                    )
+                )
+
+                # READ ANNOTATIONS
+                input_xml_dir = os.path.join(input_data_config.input_xml_dir, sub_input_dir)
+
+                xml_paths.extend(
+                    get_file_list(
+                        input_dir=input_xml_dir,
+                        search_subfolders=True,
+                        # exclude_pattern="predicted",
+                        file_extension=AnnotationFileFormats.XML,
+                    )
+                )
+        else:
+            # READ IMAGES
+            image_paths.extend(
+                get_file_list(
+                    input_dir=input_data_config.input_image_dir,
+                    search_subfolders=True,
+                    file_extension=input_data_config.image_format,
+                )
+            )
+
+            # READ ANNOTATIONS
+            xml_paths.extend(
+                get_file_list(
+                    input_dir=input_data_config.input_xml_dir,
+                    search_subfolders=True,
+                    # exclude_pattern="predicted",
+                    file_extension=AnnotationFileFormats.XML,
+                )
+            )
+
+        image_paths.sort()
+        xml_paths.sort()
+
+        return image_paths, xml_paths
+
     @staticmethod
     def __ensure_annotations_match_images(
         image_path_list: List[str], annotation_path_list: List[str]
@@ -114,121 +242,3 @@ class PascalVOCAnnotationParser(AnnotationParser):
             )
 
         return cleaned_image_path_list, cleaned_annotation_path_list
-
-    def parse(self) -> List[BaseAnnotation]:
-
-        image_path_list, annotation_path_list = self.__read_xml_file_paths()
-
-        annotations: List[BaseAnnotation] = list()
-        # Fill dictionary for implicit path replacement
-        for dataset_count, input_data_config in enumerate(self.pascal_voc_input_data):
-            if input_data_config.ignore_missing_images:
-                image_path_list = len(annotation_path_list) * [""]
-            else:
-                (image_path_list, annotation_path_list,) = self.__ensure_annotations_match_images(
-                    image_path_list=image_path_list,
-                    annotation_path_list=annotation_path_list,
-                )
-
-            for image_path, annotation_path in zip(image_path_list, annotation_path_list):
-
-                if (
-                    not input_data_config.ignore_missing_images
-                    and os.path.realpath(input_data_config.input_image_dir)
-                    in os.path.realpath(image_path)
-                    and os.path.realpath(input_data_config.input_xml_dir)
-                    in os.path.realpath(annotation_path)
-                ) or (
-                    input_data_config.ignore_missing_images
-                    and os.path.realpath(input_data_config.input_xml_dir)
-                    in os.path.realpath(annotation_path)
-                ):
-                    replacement_string = AnnotationParser.csv_directory_replacement_string.format(
-                        dataset_count
-                    )
-
-                    try:
-                        pascal_voc_builder = PascalVOCAnnotationBuilder(
-                            mapper=self.mapper,
-                            use_difficult=input_data_config.use_difficult,
-                        )
-
-                        annotation: BaseAnnotation = pascal_voc_builder.build(
-                            image_path=image_path,
-                            annotation_path=annotation_path,
-                            image_dir=input_data_config.input_image_dir,
-                            annotation_dir=input_data_config.input_xml_dir,
-                            replacement_string=replacement_string,
-                        )
-
-                        annotations.append(annotation)
-
-                    except (ValueError, ForbiddenClassError, ParseError) as error:
-                        logger.warning(
-                            "%s, annotation from path %s will be skipped",
-                            str(error),
-                            annotation_path,
-                        )
-                        continue
-
-        return annotations
-
-    def __read_xml_file_paths(self) -> Tuple[List[str], List[str]]:
-
-        image_paths = []
-        xml_paths = []
-
-        for input_data_config in self.pascal_voc_input_data:
-
-            # CHECK SUBDIR CONFIG
-            if len(input_data_config.input_sub_dirs) > 0:
-
-                for sub_input_dir in input_data_config.input_sub_dirs:
-                    # READ IMAGES
-                    input_image_dir = os.path.join(
-                        input_data_config.input_image_dir, sub_input_dir
-                    )
-
-                    image_paths.extend(
-                        get_file_list(
-                            input_dir=input_image_dir,
-                            search_subfolders=True,
-                            file_extension=f"{input_data_config.image_format}",
-                        )
-                    )
-
-                    # READ ANNOTATIONS
-                    input_xml_dir = os.path.join(input_data_config.input_xml_dir, sub_input_dir)
-
-                    xml_paths.extend(
-                        get_file_list(
-                            input_dir=input_xml_dir,
-                            search_subfolders=True,
-                            # exclude_pattern="predicted",
-                            file_extension=AnnotationFileFormats.XML,
-                        )
-                    )
-            else:
-                # READ IMAGES
-                image_paths.extend(
-                    get_file_list(
-                        input_dir=input_data_config.input_image_dir,
-                        search_subfolders=True,
-                        file_extension=input_data_config.image_format,
-                    )
-                )
-
-                # READ ANNOTATIONS
-                xml_paths.extend(
-                    get_file_list(
-                        input_dir=input_data_config.input_xml_dir,
-                        search_subfolders=True,
-                        # exclude_pattern="predicted",
-                        file_extension=AnnotationFileFormats.XML,
-                    )
-                )
-
-        image_paths.sort()
-        xml_paths.sort()
-
-        return image_paths, xml_paths
