@@ -4,23 +4,17 @@
 # For details on the licensing terms, see the LICENSE file.
 
 """Module for enumerating options of formats"""
-from enum import auto
+from enum import Enum
 
 from mlcvzoo_base.configuration.structs import BaseType
 
-try:
-    # python3.10
-    from enum import StrEnum  # type: ignore
-except ImportError:
-    from backports.strenum import StrEnum
-
 
 class CSVOutputStringFormats(BaseType):
-    BASE: str = "BASE"
-    YOLO: str = "YOLO"
+    BASE = "BASE"
+    YOLO = "YOLO"
 
 
-class MOTChallengeFormats(StrEnum):
-    MOT15 = auto()
-    MOT1617 = auto()
-    MOT20 = auto()
+class MOTChallengeFormats(Enum):
+    MOT15 = "mot15"
+    MOT1617 = "mot1617"
+    MOT20 = "mot20"
