@@ -20,10 +20,12 @@ from mlcvzoo_base.api.data.bounding_box import BoundingBox
 #   1) One entry per data items / image
 #   2) One entry per call of classes
 #   3) One entry per annotation Annotations the matches the image (1) and the class (2)
-# This is a list of BaseAnnotations in order to carry information about the image instead of just bounding boxes
+# This is a list of BaseAnnotations in order to carry information about the image
+# instead of just bounding boxes
 EVALUATION_LIST_TYPE = List[List[List[BaseAnnotation]]]  # pylint: disable=invalid-name
 
-CONFUSION_MATRIX_TYPE = List[List[int]]  # pylint: disable=invalid-name
+CONFUSION_MATRIX_TYPE = List[List[int]]
+CONFUSION_MATRIX_DICT_TYPE = Dict[str, Dict[str, int]]  # pylint: disable=invalid-name
 
 DEFAULT_INT_VALUE: Final[int] = 0
 DEFAULT_FLOAT_VALUE: Final[float] = 0.0
@@ -63,15 +65,6 @@ class ODMetrics:  # pylint: disable=too-many-instance-attributes
         return self.__repr__()
 
 
-# 1st key: iou-threshold
-# 2nd key: type of the size of the bounding-box
-# 3rd key: class-name
-# value: The computed metrics
-#
-# Dict[IOU_THRESHOLD][BBoxSizeTypes.BBOX_SIZE_TYPE][CLASS_NAME] = ODMetrics
-METRIC_DICT_TYPE = Dict[float, Dict[str, Dict[str, ODMetrics]]]  # pylint: disable=invalid-name
-
-
 @dataclass
 class MetricImageInfo:
     """
@@ -87,15 +80,19 @@ class MetricImageInfo:
     false_negative_matched_false_positive_annotation: Optional[BaseAnnotation] = None
 
 
-# 1st key: class name
-# 2nd key: image path
-# value: The MetricImageInfo for this class name and image path
-#
-# Dict[CLASS_NAME][IMAGE_PATH] = MetricImageInfo
-# Dict[IMAGE_PATH][CLASS_NAME] = MetricImageInfo
+# 1st key: Class Identifier as string
+# 2nd key: Image Path
+# 2nd value: The MetricImageInfo for this class name and image path
 METRIC_IMAGE_INFO_TYPE = Dict[str, Dict[str, MetricImageInfo]]  # pylint: disable=invalid-name
 
 
+# 1st key: iou-threshold
+# 2nd key: Type of the size of the bounding-box => Any of BBoxSizeTypes.BBOX_SIZE_TYPE
+# 3rd key: Class Identifier as string
+# value: The computed metrics of type ODMetrics
+METRIC_DICT_TYPE = Dict[float, Dict[str, Dict[str, ODMetrics]]]  # pylint: disable=invalid-name
+
+
 @dataclass
 class ODModelEvaluationMetrics:
     """
@@ -117,27 +114,37 @@ class ODEvaluationComputingData:
     Dataclass for storing data structures that are needed to computed object detection metrics
     """
 
-    # Dict[BBoxSizeTypes.BBOX_SIZE_TYPE][CLASS_NAME] = counter of ground truth data
+    # 1st key: Type of the size of the bounding-box => Any of BBoxSizeTypes.BBOX_SIZE_TYPE
+    # 2nd key: Class Identifier as string
+    # value: The number of ground truth boxes for the combination of keys
     gt_counter_dict: Dict[str, Dict[str, int]] = field(default_factory=lambda: {})
 
-    # Dict[IOU_THRESHOLD][CLASS_NAME] = Cumulative array indicating the false positives of the
-    #                                   dataset
+    # 1st key: iou-threshold
+    # 2nd key: Type of the size of the bounding-box => Any of BBoxSizeTypes.BBOX_SIZE_TYPE
+    # Cumulative array indicating the false positives of the dataset
     false_positives_dict: Dict[float, Dict[str, np.ndarray]] = field(  # type: ignore[type-arg]
         default_factory=lambda: {}
     )
 
-    # Dict[IOU_THRESHOLD][CLASS_NAME] = Cumulative array indicating the true positives of the
-    #                                   dataset
+    # 1st key: iou-threshold
+    # 2nd key: Type of the size of the bounding-box => Any of BBoxSizeTypes.BBOX_SIZE_TYPE
+    # Cumulative array indicating the true positives of the dataset
     true_positives_dict: Dict[float, Dict[str, np.ndarray]] = field(  # type: ignore[type-arg]
         default_factory=lambda: {}
     )
 
-    # Dict[IOU_THRESHOLD][CLASS_NAME] = Array indicating the score for each data item
-    scores: Dict[float, Dict[str, np.ndarray]] = field(default_factory=lambda: {})  # type: ignore[type-arg]
+    # 1st key: iou-threshold
+    # 2nd key: Type of the size of the bounding-box => Any of BBoxSizeTypes.BBOX_SIZE_TYPE
+    # value: Array indicating the score for each data item
+    scores: Dict[float, Dict[str, np.ndarray]] = field(  # type: ignore[type-arg]
+        default_factory=lambda: {}
+    )
 
-    # Dict[IOU_THRESHOLD][CLASS_NAME] = List containing all bounding boxes for each data item
+    # key: iou-threshold
     detected_annotations: Dict[float, List[BoundingBox]] = field(default_factory=lambda: {})
 
-    # Dict[IOU_THRESHOLD][BBoxSizeTypes.BBOX_SIZE_TYPE] = List indicating the AP metrics that have
-    #                                                     been computed correctly
+    # TODO: Is this needed?! => Remove at next major version update
+    # 1st key: iou-threshold
+    # 2nd key: Type of the size of the bounding-box => Any of BBoxSizeTypes.BBOX_SIZE_TYPE
+    # List indicating the AP metrics that have been computed correctly
     valid_precisions: Dict[float, Dict[str, List[float]]] = field(default_factory=lambda: {})
