@@ -9,7 +9,7 @@ import logging
 import math
 import os
 from pathlib import Path
-from typing import Any, Dict, List, Tuple
+from typing import Any, Dict, List, Optional, Tuple
 
 import cv2
 import numpy as np
@@ -18,7 +18,9 @@ from terminaltables import AsciiTable
 from mlcvzoo_base.api.data.annotation import BaseAnnotation
 from mlcvzoo_base.api.data.bounding_box import BoundingBox
 from mlcvzoo_base.api.data.box import Box
+from mlcvzoo_base.api.data.class_identifier import ClassIdentifier
 from mlcvzoo_base.evaluation.object_detection.data_classes import (
+    CONFUSION_MATRIX_DICT_TYPE,
     CONFUSION_MATRIX_TYPE,
     METRIC_DICT_TYPE,
 )
@@ -114,6 +116,12 @@ def update_annotation_data(
     Returns: stacked List of BaseAnnotations, the updated list
 
     """
+
+    logger.warning(
+        "DEPRECATED: The method 'update_annotation_data' is deprecated and not used"
+        "in any internal code anymore. It will be removed in future versions."
+    )
+
     if not 0 <= index < len(all_annotations):
         logger.debug("WARNING: Index '%s' out of range for all_annotations!", index)
         return all_annotations
@@ -272,6 +280,11 @@ def generate_fn_fp_confusion_matrix_table(
         The generated 'AsciiTable'
     """
 
+    logger.warning(
+        "DEPRECATED: The method 'generate_fn_fp_confusion_matrix_table' is deprecated"
+        "and will be removed in future versions!"
+    )
+
     table_data = [[""]]
 
     for class_id in range(0, len(confusion_matrix)):
@@ -290,6 +303,42 @@ def generate_fn_fp_confusion_matrix_table(
     return table
 
 
+def generate_fn_fp_confusion_matrix_table_from_dict(
+    confusion_matrix: CONFUSION_MATRIX_DICT_TYPE,
+) -> AsciiTable:
+    """
+    Generate a 'AsciiTable' object that represents the confusion matrix
+    of an objection detection evaluation output. The confusion matrix indicates
+    which false negative bounding boxes of a certain class could be matches to
+    false positive bounding boxes of another class.
+
+    Args:
+        confusion_matrix: The confusion Matrix as 2D Dict
+
+    Returns:
+        The generated 'AsciiTable'
+    """
+
+    table_data = [[""]]
+
+    for class_identifier_str in confusion_matrix.keys():
+        table_data[0].append(class_identifier_str)
+
+    row_data: List[Any]
+    for row_class_identifier_str in confusion_matrix.keys():
+        row_data = [row_class_identifier_str]
+        for column_class_identifier_str in confusion_matrix[row_class_identifier_str].keys():
+            row_data.append(
+                f"{confusion_matrix[row_class_identifier_str][column_class_identifier_str]}"
+            )
+        table_data.append(row_data)
+
+    table = AsciiTable(table_data)
+    table.inner_footing_row_border = False
+
+    return table
+
+
 def __draw_annotation_on_tf_image(
     img: np.ndarray,  # type: ignore[type-arg]
     annotation: BaseAnnotation,
